==> haskell-hasql-pool-0.4.3-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-pool
version: 0.4.3
id: hasql-pool-0.4.3-KsgVRSThzYw30DvDQD9zYq
key: hasql-pool-0.4.3-KsgVRSThzYw30DvDQD9zYq
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-pool
synopsis: A pool of connections for Hasql
category: Hasql, Database, PostgreSQL
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    Hasql.Pool
hidden-modules: Hasql.Pool.Prelude
abi: 4241c57a8714c43257afcb995c8a0359
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hasql-pool-0.4.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/hasql-pool-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/hasql-pool-0.4.3
hs-libraries: HShasql-pool-0.4.3-KsgVRSThzYw30DvDQD9zYq
depends:
    resource-pool-0.2.3.2-AxpUqZgHU341wPjgPw9ojm
    hasql-1.1.1-3hc8JLi58M96cywg0XAASD time-1.8.0.2
    base-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm
abi-depends: resource-pool-0.2.3.2-AxpUqZgHU341wPjgPw9ojm=be5be4e86ad49691f32784ec226ad5f3
             hasql-1.1.1-3hc8JLi58M96cywg0XAASD=67bc09eb770c57b43639841f0f7e431d
             time-1.8.0.2=7cc0324e0aef789d5f0780f6640c241b
             base-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm=208073fa5c5f239d647d4a6aa5951c23
haddock-interfaces: /usr/share/doc/haskell-hasql-pool/html/hasql-pool.haddock
haddock-html: /usr/share/doc/haskell-hasql-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-pool-0.4.3-47-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-pool
version: 0.4.3
id: hasql-pool-0.4.3-HP3qX4Kvsto58a16IdwRvg
key: hasql-pool-0.4.3-HP3qX4Kvsto58a16IdwRvg
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-pool
synopsis: A pool of connections for Hasql
category: Hasql, Database, PostgreSQL
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
indefinite: False
exposed-modules:
    Hasql.Pool
hidden-modules: Hasql.Pool.Prelude
abi: 630dd1a081710dd1a8173c8f183a9854
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hasql-pool-0.4.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/hasql-pool-0.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/hasql-pool-0.4.3
hs-libraries: HShasql-pool-0.4.3-HP3qX4Kvsto58a16IdwRvg
depends:
    resource-pool-0.2.3.2-L8h9faiaZdY6WQskuUbSwo
    hasql-1.1.1-IFUzKFNOLPA81upmCkxymU time-1.8.0.2
    base-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm
abi-depends: resource-pool-0.2.3.2-L8h9faiaZdY6WQskuUbSwo=2d5c156d9c803f2fe417e33029377450
             hasql-1.1.1-IFUzKFNOLPA81upmCkxymU=66b2242b5557ccc3ee2423e0f77d0df8
             time-1.8.0.2=7cc0324e0aef789d5f0780f6640c241b
             base-prelude-1.2.0.1-Jp4fn0lH8rP2DHoIPVF2qm=208073fa5c5f239d647d4a6aa5951c23
haddock-interfaces: /usr/share/doc/haskell-hasql-pool/html/hasql-pool.haddock
haddock-html: /usr/share/doc/haskell-hasql-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
